| lcmcrSample | R Documentation |
Perform LCMCR sampling with a monitor function
lcmcrSample(
object,
burnin = 10000,
samples = 1000,
thinning = 10,
clear_buffer = FALSE,
output = TRUE,
nMonitorBreaks = 100,
monitorFunc = function(subs, tot) {
}
)
object |
the samples |
burnin |
MCMC burn in |
samples |
number of samples |
thinning |
MCMC thinning |
clear_buffer |
buffer clear buffer of object |
output |
output progress |
nMonitorBreaks |
number of times to call the monitor function |
monitorFunc |
A function called nMonitorBreaks times taking the number of samples to be taken, and the total samples |
An edited version of lcmCR_PostSampl
The posterior sample of N estimates
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.